<?php

global $modify_text;
$modify_text = array (

'modify'                =>        'Modify',
'noticefrom'            =>        'Notice from',
'hasopened'             =>        'has OPENED A NEW Flyspray task, and assigned it to you:',
'newtask'               =>        'New Task:',
'moreinfonew'           =>        'You can find more information about this bug at the Flyspray page:',
'newtaskcategory'       =>        'A new Flyspray task has been opened in this category',
'categoryowner'         =>        'You are receiving this because you are listed as the category owner.',
'tasksummary'           =>        'Task summary:',
'newtaskadded'          =>        'Your new task has been added.',
'waitwhiletransfer'     =>        'Please wait while you are transferred...',
'clicknowait'           =>        'Click here if you do not wish to wait.',
'summaryanddetails'     =>        'You need to fill in both the summary and the details.',
'goback'                =>        'Go back.',

'summary'               =>        'Summary:',
'tasktype'              =>        'Task Type:',
'category'              =>        'Category:',
'status'                =>        'Status:',
'operatingsystem'       =>        'Operating System:',
'severity'              =>        'Severity:',
'reportedversion'       =>        'Reported Version:',
'dueinversion'          =>        'Due in Version:',
'percentcomplete'       =>        'Percent Complete:',
'summary'               =>        'Summary:',
'details'               =>        'Details:',

'messagefrom'           =>        'This is a message from the Flyspray bug tracking system at',
'hasjustmodified'       =>        'has just modified the following task.',
'changedfields'         =>        'Changed fields are prefixed with asterisks (**)',
'moreinfomodify'        =>        'You can get more information about this task at the following URL:',

'task'                  =>        'Task',
'nolongerassigned'      =>        'The following task is no longer assigned to you.  It is now assigned to',
'hasassigned'           =>        'has assigned to you the following Flyspray task:',

'taskupdated'           =>        'Task has been updated.',

'hasclosedassigned'     =>        'has closed the following Flyspray task that you were assigned:',
'reasonforclosing'      =>        'The reason for closing is:',
'noone'                 =>        'No-one',
'unassigned'            =>        'Unassigned',

'hasclosed'             =>        'has closed the following task.',
'youonnotify'           =>        'You are receiving this because you are on the notification list.',
'taskclosed'            =>        'Task has been closed.',
'returntotask'          =>        'Return to the task details',
'backtoindex'           =>        'Go back to the task list',
'noclosereason'         =>        'You didn\'t select a reason for closing this task.',
'hasreopened'           =>        'has re-opened the following Flyspray task that you closed:',
'taskreopened'          =>        'Task has been re-opened.',
'backtotask'            =>        'Go back to the task.',

'commentadded'          =>        'Comment has been added.',
'commenttoassigned'     =>        'has added a comment to a task that you have been assigned:',
'commenttotask'         =>        'has added the following comment to this task.',
'nocommententered'      =>        'You really should enter a comment before clicking the submit button.',

'fillinfields'          =>        'You didn\'t fill in all the fields.',
'notcurrentpass'        =>        'That\'s not your current password!',
'passchanged'           =>        'Your password has been changed.',
'closewindow'           =>        'You can now close this window.',
'passnomatch'           =>        'Your new passwords weren\'t the same!',

'usernametaken'         =>        'That username is already taken.',
'newusercreated'        =>        'New User Account has been created.',
'accountcreated'        =>        'Your account has been created.',
'newuserwarning'        =>        'Note that the global preferences might require your account to be approved by an admin.  If you cannot login, this is probably why.',
'nomatchpass'           =>        'Passwords didn\'t match.',
'confirmwrong'          =>        'Confirmation code is incorrect!',
'formnotcomplete'       =>        'Form was not completely filled in.',

'groupnametaken'        =>        'That Group name is already taken.',
'newgroupadded'         =>        'New Group added.',

'optionssaved'          =>        'Flyspray Options saved.',

'hasuploaded'           =>        'has uploaded a file attachment to a task that have been assigned:',
'hasattached'           =>        'has attached a file to the following task.',
'filename'              =>        'Filename:',
'description'           =>        'Description:',
'fileuploaded'          =>        'File has been uploaded.',
'fileerror'             =>        'There was an error uploading your file.  Perhaps the permissions on the <i>attachments/</i> directory are incorrect.',
'contactadmin'          =>        'Contact the Administrator for this project.',
'selectfileerror'       =>        'You didn\'t select a file.',  // Changed in 0.9.6

'userupdated'           =>        'User details have been updated',
'realandemail'          =>        'You didn\'t fill in both the Real Name and Email Address fields.', // Not used from 0.9.7

'groupupdated'          =>        'Group definition updated.',
'groupanddesc'          =>        'You didn\'t fill in the Group name and description fields.',

'fillallfields'         =>        'Please fill in all fields.',
'listupdated'           =>        'List has been updated.',
'listitemadded'         =>        'New list item added.',

'relatedadded'          =>        'Related task added to list.',
'relatederror'          =>        'That task is already on this related task list.',

'relatedremoved'        =>        'Related task removed from list.',

'notifyadded'           =>        'User added to notification list.',
'notifyerror'           =>        'That user is already on the notification list for that task.',

'notifyremoved'         =>        'User removed from notification list.',

'editcommentsaved'      =>        'Updated comment saved.',
'commentdeleted'        =>        'Comment has been deleted.',

// Added in version 0.9.5

'project'               =>        'Project:',
'gotonewtask'           =>        'Go to the new task you just created',
'addanother'            =>        'Add another task to this Project',
'projectcreated'        =>        'Your new Project has been created.  Follow the link below to set up your category, operating system and version lists',
'customiseproject'      =>        'Customise this project',
'projectupdated'        =>        'Project preferences updated',
'emptytitle'            =>        'You left the Project Title field blank.  Go back and fix it.',
'loginbelow'            =>        'You may now attempt to login.',      // Changed in version 0.9.8
'attachmentdeleted'     =>        'The attachment has been deleted',

// Added in 0.9.6

'reminderadded'         =>        'Your reminder has been added.',
'reminderdeleted'       =>        'The selected reminder has been deleted.',
'flyspraytask'          =>        'Flyspray task',
'fieldsmissing'         =>        'Some fields contained no or invalid data.',
'relatedinvalid'        =>        'There is no such task.',
'relatedproject'        =>        'Task is attached to a different project.',
'addanyway'             =>        'Add anyway',
'cancel'                =>        'Cancel',
'alreadyedited'         =>        'This task was edited by someone else before you saved.',
'saveanyway'            =>        'Save my changes anyway',
'priority'              =>        'Priority',

// Added in version 0.9.7

'nouserselected'        =>        'No user selected.  Select at least one user before trying again.',  // Changed in svn r191
'groupswitchupdated'    =>        'User groups modified successfully.',
'takenownership'        =>        'This task is now assigned to you.',
'adminrequestmade'      =>        'Your request has been sent to a Project Manager.',
'newdepnotify'          =>        'A new dependency has been added to the following task:',
'dependadded'           =>        'Task dependency has been added',
'dependaddfailed'       =>        'You can\'t add that task as a dependency at this time',
'depremoved'            =>        'Task dependency has been removed',
'newdepis'              =>        'The new dependency is',
'magicurlsent'          =>        'A message has been sent to your notification address.  It contains a link that will take you to a page to complete this task.',
'changefspass'          =>        'Change Flyspray password',
'magicurlmessage'       =>        'Please follow the link below to change your Flyspray password:',
'erroronform'           =>        'There was an problem with your form submission',
'addressused'           =>        'This address has been used to register a Flyspray account.  If you were not expecting this message, please ignore and delete it.  Go to the following URL to complete your registration:',
'confirmcodeis'         =>        'Your confirmation code is:',
'codesent'              =>        'Your confirmation code has been sent.  Please follow the instructions contained in the message.',
'taskmadeprivate'       =>        'This task has been made private',
'taskmadepublic'        =>        'This task has been made public again',
'realandnotify'         =>        'You need to fill in the Real Name field, and either the Email Address or Jabber ID field.',


// Added in version 0.9.8

'pmreqdenied'           =>       'Project Manager request denied',
'massopsuccess'         =>       'Mass operations successful - where permissions allowed',
'usernotexist'          =>       'That username does not exist on this Flyspray installation',
'commentattachperms'    =>       'You cannot delete that comment - no permission to delete attachments',
);
?>
